@@ -25,6 +25,7 @@
 #include <QLoggingCategory>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 
@@ -74,6 +75,8 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
     MainWindow mainWindow;
     QSize size(800, 600);
     mainWindow.setMinimumSize(size);
